"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFalse = void 0;
const core_1 = require("@serenity-js/core");
const equals_1 = require("./equals");
/**
 * Creates an {@apilink Expectation|expectation} that is met when the actual `boolean` value
 * is `false`.
 *
 * ## Ensuring that a given value is false
 *
 * ```ts
 * import { actorCalled } from '@serenity-js/core'
 * import { Ensure, isFalse } from '@serenity-js/assertions'
 * import { Cookie } from '@serenity-js/web'
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that(Cookie.called('example-regular-cookie').isSecure(), isFalse()),
 * )
 * ```
 *
 * @group Expectations
 */
function isFalse() {
    return core_1.Expectation.to(`equal false`).soThatActual((0, equals_1.equals)(false));
}
exports.isFalse = isFalse;
//# sourceMappingURL=isFalse.js.map